@@ -1,5 +1,5 @@
 from concurrent.futures import Future
-from threading import Thread
+from threading import Thread, Lock
 
 from pykusto.client import PyKustoClient, Database
 from pykusto.expressions import StringColumn, NumberColumn, AnyTypeColumn, BooleanColumn
@@ -14,11 +14,11 @@ class TestClientFetch(TestBase):
             columns_response=mock_columns_response([('foo', KustoType.STRING), ('bar', KustoType.INT)]),
             record_metadata=True,
         )
-        table = PyKustoClient(mock_kusto_client, fetch_by_default=False)['test_db']['test_table']
+        table = PyKustoClient(mock_kusto_client, fetch_by_default=False)['test_db']['mock_table']
         table.blocking_refresh()
         # Fetch query
         self.assertEqual(
-            [RecordedQuery('test_db', '.show table test_table | project AttributeName, AttributeType | limit 10000')],
+            [RecordedQuery('test_db', '.show table mock_table | project AttributeName, AttributeType | limit 10000')],
             mock_kusto_client.recorded_queries,
         )
         # Dot notation
@@ -40,7 +40,7 @@ class TestClientFetch(TestBase):
 
         try:
             mock_kusto_client = MockKustoClient(upon_execute=upon_execute, record_metadata=True)
-            table = PyKustoClient(mock_kusto_client, fetch_by_default=False)['test_db']['test_table']
+            table = PyKustoClient(mock_kusto_client, fetch_by_default=False)['test_db']['mock_table']
             table.refresh()
             self.assertEqual(type(table['foo']), AnyTypeColumn)
             self.assertEqual(type(table['bar']), AnyTypeColumn)
@@ -60,17 +60,23 @@ class TestClientFetch(TestBase):
         mock_response_future.returned_queries = []
         mock_response_future.called = False
         mock_response_future.executed = False
+        future_called_lock = Lock()
 
         def upon_execute(query):
-            if not mock_response_future.called:
-                mock_response_future.called = True
+            with future_called_lock:
+                if mock_response_future.called:
+                    first_run = False
+                else:
+                    mock_response_future.called = True
+                    first_run = True
+            if first_run:
                 mock_response_future.result()
                 mock_response_future.executed = True
             mock_response_future.returned_queries.append(query)
 
         try:
             mock_kusto_client = MockKustoClient(upon_execute=upon_execute, record_metadata=True)
-            table = PyKustoClient(mock_kusto_client, fetch_by_default=False)['test_db']['test_table']
+            table = PyKustoClient(mock_kusto_client, fetch_by_default=False)['test_db']['mock_table']
             table.refresh()
 
             # Executing a query in a separate thread, because it is supposed to block until the fetch returns
@@ -90,15 +96,15 @@ class TestClientFetch(TestBase):
         # Before the fix the order of returned query was reversed
         self.assertEqual(
             [
-                RecordedQuery('test_db', '.show table test_table | project AttributeName, AttributeType | limit 10000'),
-                RecordedQuery('test_db', 'test_table | take 5'),
+                RecordedQuery('test_db', '.show table mock_table | project AttributeName, AttributeType | limit 10000'),
+                RecordedQuery('test_db', 'mock_table | take 5'),
             ],
             mock_response_future.returned_queries,
         )
 
     def test_table_fetch(self):
         mock_kusto_client = MockKustoClient(
-            tables_response=mock_tables_response([('test_table', [('foo', KustoType.STRING), ('bar', KustoType.INT)])]),
+            tables_response=mock_tables_response([('mock_table', [('foo', KustoType.STRING), ('bar', KustoType.INT)])]),
             record_metadata=True,
         )
         db = PyKustoClient(mock_kusto_client, fetch_by_default=False)['test_db']
@@ -107,7 +113,7 @@ class TestClientFetch(TestBase):
             [RecordedQuery('test_db', '.show database schema | project TableName, ColumnName, ColumnType | limit 10000')],
             mock_kusto_client.recorded_queries,
         )
-        table = db.test_table
+        table = db.mock_table
         # Table columns
         self.assertEqual(type(table.foo), StringColumn)
         self.assertEqual(type(table.bar), NumberColumn)
@@ -199,7 +205,7 @@ class TestClientFetch(TestBase):
 
     def test_database_fetch(self):
         mock_kusto_client = MockKustoClient(
-            databases_response=mock_databases_response([('test_db', [('test_table', [('foo', KustoType.STRING), ('bar', KustoType.INT)])])]),
+            databases_response=mock_databases_response([('test_db', [('mock_table', [('foo', KustoType.STRING), ('bar', KustoType.INT)])])]),
             record_metadata=True,
         )
         client = PyKustoClient(mock_kusto_client)
@@ -209,7 +215,7 @@ class TestClientFetch(TestBase):
             mock_kusto_client.recorded_queries,
         )
         # Table columns
-        table = client.test_db.test_table
+        table = client.test_db.mock_table
         self.assertEqual(type(table.foo), StringColumn)
         self.assertEqual(type(table.bar), NumberColumn)
         self.assertEqual(type(table['baz']), AnyTypeColumn)
@@ -219,31 +225,31 @@ class TestClientFetch(TestBase):
         self.assertEqual(type(db), Database)
         self.assertEqual('test_db', db.get_name())
         self.assertEqual(('test_db',), tuple(client.get_databases_names()))
-        self.assertEqual(('test_table', 'other_table'), tuple(client.test_db.get_table_names()))
-        self.assertEqual(('foo', 'bar', 'baz'), tuple(client.test_db.test_table.get_columns_names()))
-        self.assertTrue({'foo', 'bar'} < set(dir(client.test_db.test_table)))
-        self.assertEqual('PyKustoClient(test_cluster.kusto.windows.net).Database(test_db).Table(test_table)', repr(client.test_db.test_table))
+        self.assertEqual(('mock_table', 'other_table'), tuple(client.test_db.get_table_names()))
+        self.assertEqual(('foo', 'bar', 'baz'), tuple(client.test_db.mock_table.get_columns_names()))
+        self.assertTrue({'foo', 'bar'} < set(dir(client.test_db.mock_table)))
+        self.assertEqual('PyKustoClient(test_cluster.kusto.windows.net).Database(test_db).Table(mock_table)', repr(client.test_db.mock_table))
 
     def test_autocomplete_with_dot(self):
         mock_kusto_client = MockKustoClient(
-            databases_response=mock_databases_response([('test_db', [('test_table', [('foo', KustoType.STRING), ('bar.baz', KustoType.INT)])])]),
+            databases_response=mock_databases_response([('test_db', [('mock_table', [('foo', KustoType.STRING), ('bar.baz', KustoType.INT)])])]),
             record_metadata=True,
         )
         client = PyKustoClient(mock_kusto_client)
         client.wait_for_items()
         # Table columns
-        table = client.test_db.test_table
+        table = client.test_db.mock_table
         self.assertEqual(type(table.foo), StringColumn)
         self.assertEqual(type(table.bar), AnyTypeColumn)
         self.assertEqual(type(table['bar.baz']), NumberColumn)
-        autocomplete_list = set(dir(client.test_db.test_table))
+        autocomplete_list = set(dir(client.test_db.mock_table))
         self.assertIn('foo', autocomplete_list)
         self.assertNotIn('bar.baz', autocomplete_list)
 
     def test_empty_database(self):
         mock_kusto_client = MockKustoClient(
             databases_response=mock_databases_response([
-                ('test_db', [('test_table', [('foo', KustoType.STRING), ('bar', KustoType.INT)])]),
+                ('test_db', [('mock_table', [('foo', KustoType.STRING), ('bar', KustoType.INT)])]),
                 ('', [('test_table1', [('foo1', KustoType.STRING), ('bar1', KustoType.INT)])])
             ]),
             record_metadata=True,
@@ -254,7 +260,7 @@ class TestClientFetch(TestBase):
             [RecordedQuery('', '.show databases schema | project DatabaseName, TableName, ColumnName, ColumnType | limit 100000')],
             mock_kusto_client.recorded_queries,
         )
-        self.assertEqual(type(client.test_db.test_table.foo), StringColumn)
+        self.assertEqual(type(client.test_db.mock_table.foo), StringColumn)
 
     def test_client_not_fetched(self):
         client = PyKustoClient(MockKustoClient(), fetch_by_default=False)
